#
# spec file for package xfce4-battery-plugin
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.16.0
%define plugin battery
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        1.2.0
Release:        1.1
Summary:        Battery Monitoring Plugin for the Xfce Panel
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-battery-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/1.2/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gettext >= 0.19.8
BuildRequires:  meson >= 0.54.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0) >= 2.50.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4util-1.0) >= %{panel_version}
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Requires:       xfce4-panel >= %{panel_version}
# uses exo-open
Requires:       exo-tools
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The Battery plugin allows to monitor battery levels and can execute actions on
low and critical levels.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-maintainer-mode \
  --disable-static
%else
%meson
%endif
%meson_build

%install
%meson_install

rm -f %{buildroot}%{_libdir}/xfce4/panel/plugins/libbattery.la

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS NEWS README.md
%license COPYING COPYING.LIB
%{_libdir}/xfce4/panel/plugins/libbattery.so
%{_datadir}/icons/hicolor/*/apps/xfce4-battery-*.*
%{_datadir}/xfce4/panel/plugins/battery.desktop

%files lang -f %{name}.lang

%changelog
* Tue May 27 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.2.0
  Meson has been added as a build system in this release, and the
  associated archive has been generated by 'meson dist'. Although
  autotools has been retained for the time being and can still be used
  via 'autogen.sh', meson is now the preferred build system, and
  autotools will be removed in a future release.
  * Update README after switchover to meson
  * build: Automate copyright year management
  * meson-build: Use shared_module()
  * Replace deprecated exo with libxfce4ui 4.21.0
  * meson-build: Do not install Makefile.in
  * build: Use VERSION_FULL instead of PACKAGE_VERSION
  * Add meson build
  * Translation Updates
* Sun Dec 29 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.1.6
  * Update copyright year
  * Introduce Darwin support
  * build: Bump dependency versions and fix deprecation warnings
  * I18n: Update po/LINGUAS list
  * build: Use XDT_VERSION_INIT and get rid of configure.ac.in
  * gcc-analyzer: Fix -Wanalyzer-null-dereference
  * scan-build: Fix deadcode.DeadStores
  * I18n: Update po/LINGUAS list
  * build: Get rid of intltool
  * Add initial envsys support for NetBSD
  * Translation Updates
* Thu Apr 20 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.1.5
  * Update copyright year
  * build: Add GLib requirement
  * Replace deprecated XfcePanelImage with GtkImage
  * Update `.gitignore`
  * Use "logo-icon-name" instead of "logo" in about dialog
  * Fix make distcheck
  * Respect panel setting "Adjust size automatically"
  * Update COPYING
  * Translation Updates
- Remove _service file
* Tue Mar 23 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.1.4
  * Add help button to properties dialog
  * Drop subtitle from settings dialog
  * Fix labels alignment for very small panels
  * Fix compilation warnings
  * automake: INCLUDES -> AM_CPPFLAGS
  * autoconf: Some updates
  * Remove unnecessary boxes
  * Remove GSourceFunc casts
  * Add new README.md, update AM_INIT_AUTOMAKE
  * Add basic GitLab pipeline
  * Update URLs from goodies.xfce.org to docs.xfce.org (bxo#16154)
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Wed Aug 14 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.1.3
  * Fix some warnings reported by Clang (bxo#15037)
  * Avoid unnecessary strdup (bxo#15196)
  * Replace GtkStock buttons
  * Translation updates
* Tue Jul 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added bcond for git master builds
- Don't add Changelog. NEWS is enough
* Tue Jan 15 2019 Maurizio Galli <maurizio.galli@gmail.com>
- update to version 1.1.2
  - support for APM has been removed
  - Listen for UPower events for power source changes (bxo#14978)
  - Reset averages when a battery is removed/added (bxo#14930)
  - Re-detect battery presence every 30 seconds (bxo#14930)
  - Fix null pointer dereference with no battery present (bxo#14930)
  - Remove deprecated /proc/acpi support in favor of sysfs
  - Remove APM support on FreeBSD as well, it doesn't even build
  - Remove historical APM support for Linux, support ACPI only
  - Initially show/hide widgets according to user config (bxo#9594)
* Mon Oct 15 2018 Stefan Seyfried <seife+obs@b1-systems.com>
- update to version 1.1.1:
  - Avoid memory leaks
  - Bump to minimal Gtk to 3.16
  - Only set progressbar width or height depending on the
    orientation (bxo#12942)
  - Create a single GtkCssProvider in setup_battmon() (bxo#12975)
  - Improved spacing and layout in dialogs (bxo#14659)
- use %%license tag for license files
* Tue Oct  3 2017 jengelh@inai.de
- Remove redundant %%clean section.
* Sun Nov 27 2016 seife+obs@b1-systems.com
- update to 1.1.0
  - port to gtk+3/libxfce4ui-2/libxfce4panel-2.0
* Sun Jul  1 2012 gber@opensuse.org
- update to version 1.0.5
  - better compliance with the panel plugin HIG
  - don't set labels orientation on 4.8 panels
  - set progressbar orientation in setup_battmon
* Mon May 14 2012 gber@opensuse.org
- update to version 1.0.4
  - improve the plugin UI in vertical/deskbar/multirows panels
* Mon Apr 30 2012 gber@opensuse.org
- update to version 1.0.2
  - change icon depending on charge level/ac status
  - install icons from xfpm
  - add AC color state and allow user-configurable colors
  - make the progressbar optional
  - improve battery removal detection
  - rework configuration dialog to use tabs
  - only display time if it's valid
* Sun Apr 29 2012 gber@opensuse.org
- add dependency on exo-tools since exo-open is used
* Fri Apr 20 2012 gber@opensuse.org
- add documentation files
* Tue Apr 17 2012 gber@opensuse.org
- fix source URL
* Tue Apr 17 2012 gber@opensuse.org
- update to version 1.0.1
  - build the plugin as a module
  - port to libxfce4ui
  - port to panel 4.9+
  - add about dialog
  - don't show percentage/time if charge is 0
- dropped obsolete
  xfce4-battery-plugin-1.0.0-show-time-when-on-battery-power.patch
* Tue Apr  3 2012 gber@opensuse.org
- added
  xfce4-battery-plugin-1.0.0-show-time-when-on-battery-power.patch
  in order to show the time when on battery power (bxo#3736)
* Sun Apr  1 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
* Fri Sep 16 2011 andrea.turrini@gmail.com
- fixed typo in xfce4-panel-plugin-battery.spec
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
